"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.transpilePaths = exports.transpile = undefined;

var _bluebirdLst;

function _load_bluebirdLst() {
    return _bluebirdLst = require("bluebird-lst");
}

let transpile = exports.transpile = (() => {
    var _ref = (0, (_bluebirdLst || _load_bluebirdLst()).coroutine)(function* (transpilator) {
        const paths = process.argv.slice(2);
        if (paths.length == 0) {
            paths.push(process.cwd());
        }
        return transpilePaths(paths, transpilator);
    });

    return function transpile(_x) {
        return _ref.apply(this, arguments);
    };
})();

let transpilePaths = exports.transpilePaths = (() => {
    var _ref2 = (0, (_bluebirdLst || _load_bluebirdLst()).coroutine)(function* (paths, transpilator) {
        for (const basePath of paths) {
            try {
                yield build(basePath, transpilator);
            } catch (e) {
                if (!(e instanceof CompilationError)) {
                    throw e;
                }
                for (const diagnostic of e.errors) {
                    if (diagnostic.file == null) {
                        console.log(diagnostic.messageText);
                        continue;
                    }
                    const location = diagnostic.file.getLineAndCharacterOfPosition(diagnostic.start);
                    const message = (_typescript || _load_typescript()).flattenDiagnosticMessageText(diagnostic.messageText, '\n');
                    console.log(`${diagnostic.file.fileName} (${location.line + 1}, ${location.character + 1}): ${message}`);
                }
                process.exit(-1);
                return;
            }
        }
    });

    return function transpilePaths(_x2, _x3) {
        return _ref2.apply(this, arguments);
    };
})();

let build = (() => {
    var _ref3 = (0, (_bluebirdLst || _load_bluebirdLst()).coroutine)(function* (basePath, transpilator) {
        const tsConfigPath = _path.join(basePath, "tsconfig.json");
        const jsonResult = (_typescript || _load_typescript()).parseConfigFileTextToJson(tsConfigPath, (yield (0, (_fsExtraP || _load_fsExtraP()).readFile)(tsConfigPath, "utf8")));
        if (jsonResult.error != null) {
            throw new CompilationError([jsonResult.error]);
        }
        const result = (_typescript || _load_typescript()).parseJsonConfigFileContent(jsonResult.config, (_typescript || _load_typescript()).sys, basePath);
        checkErrors(result.errors);
        yield transpilator(basePath, result, jsonResult.config);
    });

    return function build(_x4, _x5) {
        return _ref3.apply(this, arguments);
    };
})();

exports.checkErrors = checkErrors;
exports.processTree = processTree;

var _typescript;

function _load_typescript() {
    return _typescript = _interopRequireWildcard(require("typescript"));
}

var _path = _interopRequireWildcard(require("path"));

var _fsExtraP;

function _load_fsExtraP() {
    return _fsExtraP = require("fs-extra-p");
}

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function checkErrors(errors) {
    if (errors.length !== 0) {
        throw new CompilationError(errors);
    }
}
class CompilationError extends Error {
    constructor(errors) {
        super("Compilation error");
        this.errors = errors;
    }
}
function processTree(sourceFile, replacer) {
    let cursorPosition = 0;
    function skip(node) {
        cursorPosition = node.end;
    }
    function readThrough(node) {
        cursorPosition = node.pos;
    }
    function visit(node) {
        readThrough(node);
        if (node.flags & (_typescript || _load_typescript()).ModifierFlags.Private) {
            // skip private nodes
            skip(node);
            return;
        }
        if (replacer(node)) {
            skip(node);
        } else {
            (_typescript || _load_typescript()).forEachChild(node, visit);
        }
    }
    visit(sourceFile);
}
//# sourceMappingURL=util.js.map